# Cloud UI

> The Cloud UI provides a web interface for interacting with OpenHands. This page provides references on how to use the OpenHands Cloud UI.

## Landing Page

The landing page is where you can:

* [Select a GitHub repo](/openhands/usage/cloud/github-installation#working-with-github-repos-in-openhands-cloud),
  [a GitLab repo](/openhands/usage/cloud/gitlab-installation#working-with-gitlab-repos-in-openhands-cloud) or
  [a Bitbucket repo](/openhands/usage/cloud/bitbucket-installation#working-with-bitbucket-repos-in-openhands-cloud) to start working on.
* Launch an empty conversation using `New Conversation`.
* See `Suggested Tasks` for repositories that OpenHands has access to.
* See your `Recent Conversations`.

## Settings

Settings are divided across tabs, with each tab focusing on a specific area of configuration.

* `User`
  * Change your email address.
* `Integrations`
  * [Configure GitHub repository access](/openhands/usage/cloud/github-installation#modifying-repository-access) for OpenHands.
  * [Install the OpenHands Slack app](/openhands/usage/cloud/slack-installation).
* `Application`
  * Set your preferred language, notifications and other preferences.
  * Toggle task suggestions on GitHub.
  * Toggle Solvability Analysis.
  * [Set a maximum budget per conversation](/openhands/usage/settings/application-settings#setting-maximum-budget-per-conversation).
  * [Configure the username and email that OpenHands uses for commits](/openhands/usage/settings/application-settings#git-author-settings).
* `LLM`
  * [Choose to use another LLM or use different models from the OpenHands provider](/openhands/usage/settings/llm-settings).
* `Billing`
  * Add credits for using the OpenHands provider.
* `Secrets`
  * [Manage secrets](/openhands/usage/settings/secrets-settings).
* `API Keys`
  * [Create API keys to work with OpenHands programmatically](/openhands/usage/cloud/cloud-api).
* `MCP`
  * [Setup an MCP server](/openhands/usage/settings/mcp-settings)

## Key Features

For an overview of the key features available inside a conversation, please refer to the [Key Features](/openhands/usage/key-features)
section of the documentation.

## Next Steps

* [Use OpenHands with your GitHub repositories](/openhands/usage/cloud/github-installation).
* [Use OpenHands with your GitLab repositories](/openhands/usage/cloud/gitlab-installation).
* [Use the Cloud API](/openhands/usage/cloud/cloud-api) to programmatically interact with OpenHands.


---

> To find navigation and other pages in this documentation, fetch the llms.txt file at: https://docs.openhands.dev/llms.txt